(register! {:keys [tag child-tag render on-failure on-pending on-connect
on-writing observed-attributes]})Register a resource-consumer custom element from a config: :tag element tag name :child-tag the driven child element, cached on connect :render (fn [child accepted this]), called when :last-accepted changes :on-failure (fn [child failure this]), optional, called when :last-failure changes, with failure nil on recovery so the component can clear its UI :on-pending (fn [child pending this]), optional, called when :pending? changes :on-writing (fn [child writing this]), optional, called when :writing? changes :on-connect (fn [this]), optional extra wiring :observed-attributes — optional, defaults to #js []
Register a resource-consumer custom element from a config: :tag element tag name :child-tag the driven child element, cached on connect :render (fn [child accepted this]), called when :last-accepted changes :on-failure (fn [child failure this]), optional, called when :last-failure changes, with failure nil on recovery so the component can clear its UI :on-pending (fn [child pending this]), optional, called when :pending? changes :on-writing (fn [child writing this]), optional, called when :writing? changes :on-connect (fn [this]), optional extra wiring :observed-attributes — optional, defaults to #js []
(submit-intent! consumer patch)Send an intent patch from a gesture handler back to the server-resource.
Send an intent patch from a gesture handler back to the server-resource.
(submit-write! consumer payload)Send a write from a gesture handler back to the server-resource.
Send a write from a gesture handler back to the server-resource.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |