barebuild.decorator


currentcljs

(current)

The registered decorator, or nil when the app registered none.

The registered decorator, or nil when the app registered none.
sourceraw docstring

set-request-decorator!cljs

(set-request-decorator! f)

Install f, called with each request value and returning the headers to merge into it, or a promise of them. Nil clears it.

Install `f`, called with each request value and returning the headers to merge into it, or a
promise of them. Nil clears it.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries