(current)The registered decorator, or nil when the app registered none.
The registered decorator, or nil when the app registered none.
(set-request-decorator! f)Install f, called with each request value and returning the headers to merge into it, or a
promise of them. Nil clears it.
Install `f`, called with each request value and returning the headers to merge into it, or a promise of them. Nil clears it.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |