(drifted? r)If a new intent appeared while an old one was still in flight, signal it
If a new intent appeared while an old one was still in flight, signal it
(installable? r response)Ensure that the live request matches the in-flight request id.
Ensure that the live request matches the in-flight request id.
(render-key accepted)In order to check if an accepted envelope, remove the added request/id so that it can be compared to the saved value
In order to check if an accepted envelope, remove the added request/id so that it can be compared to the saved value
(step resource event)Takes a resource and event and returns (a possibly updated) resource and the effects that need to be called. Each step gets a unique resource/id
Takes a resource and event and returns (a possibly updated) resource and the effects that need to be called. Each step gets a unique resource/id
(write-request endpoint write-id {:keys [op id record]} query)The :write effect value for a write payload, or nil when none can be built
The :write effect value for a write payload, or nil when none can be built
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |