barebuild.resource


drifted?cljs

(drifted? r)

If a new intent appeared while an old one was still in flight, signal it

If a new intent appeared while an old one was still in flight, signal it
sourceraw docstring

installable?cljs

(installable? r response)

Ensure that the live request matches the in-flight request id.

Ensure that the live request matches the in-flight request id.
sourceraw docstring

pending?cljs

(pending? r)
source

stepcljs

(step resource event)

Takes a resource and event and returns (a possibly updated) resource and the effects that need to be called. Each step gets a unique resource/id

Takes a resource and event and returns (a possibly updated) resource
and the effects that need to be called. Each step gets a unique resource/id
sourceraw docstring

writing?cljs

(writing? r)
source

cljdoc builds & hosts documentation for Clojure/Script libraries