(drifted? r)If a new intent appeared while an old one was still in flight, signal it
If a new intent appeared while an old one was still in flight, signal it
(installable? r response)Ensure that the live request matches the in-flight request id.
Ensure that the live request matches the in-flight request id.
(step resource event)Takes a resource and event and returns (a possibly updated) resource and the effects that need to be called. Each step gets a unique resource/id
Takes a resource and event and returns (a possibly updated) resource and the effects that need to be called. Each step gets a unique resource/id
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |