barebuild.utils


build-scoped-urlcljs

(build-scoped-url search pathname resource-id new-params)

Build the url from parameter set in the resource using the resource-id. e.g. {:sort "start" :direction "asc" -> tasks.sort=start&tasks.direction=asc

Build the url from parameter set in the resource using the resource-id.
e.g. {:sort "start" :direction "asc" -> tasks.sort=start&tasks.direction=asc
sourceraw docstring

canonicalize-querycljs

(canonicalize-query q)

Public function that ensures all query keys are keywords and values are non-blank strings. Entries whose value is nil or blank are dropped

Public function that ensures all query keys are keywords and values are non-blank strings.
Entries whose value is nil or blank are dropped
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries